==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/AssigningRadialMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningRadialStyleEventArgsBaseDescriptionMetadata } from "./AssigningRadialStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialMarkerStyleEventArgsDescription } from "./AssigningRadialMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningRadialMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningRadialMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ad("AssigningRadialMarkerStyleEventArgs", () => new AssigningRadialMarkerStyleEventArgsDescription());
            a.ac("AssigningRadialMarkerStyleEventArgs", AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, 'AssigningRadialMarkerStyleEventArgsDescriptionMetadata');
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialMarkerStyleEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/AssigningRadialMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningRadialStyleEventArgsBaseDescriptionMetadata } from "./AssigningRadialStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialMarkerStyleEventArgsDescription } from "./AssigningRadialMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
export let AssigningRadialMarkerStyleEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningRadialMarkerStyleEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a == null) {
                AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningRadialMarkerStyleEventArgsDescriptionMetadata.c(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
            }
            if (a.k(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningRadialMarkerStyleEventArgsDescriptionMetadata.b(a);
            a.ae("AssigningRadialMarkerStyleEventArgs", () => new AssigningRadialMarkerStyleEventArgsDescription());
            a.ad("AssigningRadialMarkerStyleEventArgs", AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a);
        }
    }
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialMarkerStyleEventArgsDescriptionMetadata, 'AssigningRadialMarkerStyleEventArgsDescriptionMetadata');
    AssigningRadialMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialMarkerStyleEventArgsDescriptionMetadata;
})();
